@@ -25,6 +25,19 @@ module Itamae
       option :log_level, type: :string, aliases: ['-l'], default: 'info'
       option :color, type: :boolean, default: true
       option :config, type: :string, aliases: ['-c']
+      option :tmp_dir, type: :string, aliases: ['-t'], default: "/tmp/itamae_tmp"
+    end
+
+    def self.options
+      @itamae_options ||= super.dup.tap do |options|
+        if config = options[:config]
+          options.merge!(YAML.load_file(config))
+        end
+      end
+    end
+
+    def self.exit_on_failure?
+      true
     end
 
     desc "local RECIPE [RECIPE...]", "Run Itamae locally"
@@ -117,14 +130,6 @@ module Itamae
     end
 
     private
-    def options
-      @itamae_options ||= super.dup.tap do |options|
-        if config = options[:config]
-          options.merge!(YAML.load_file(config))
-        end
-      end
-    end
-
     def validate_generate_target!(command, target)
       unless GENERATE_TARGETS.include?(target)
         msg = %Q!ERROR: "itamae #{command}" was called with "#{target}" !
